#pragma once

#if PLATFORM_ANDROID

#include "Android/AndroidApplication.h"
#include "Android/AndroidJNI.h"

#endif

enum AirbridgeCallbackType
{
 HandleDeeplink,
 HandleDeferredDeeplink,
 Click,
 Impression,
 FetchDeviceUUID,
 FetchAirbridgeGeneratedUUID,
};

#if PLATFORM_ANDROID

/**
 * Retrieves the callback type as an integer from a Java object.
 *
 * @param Env JNI environment pointer.
 * @param This Java object for which the callback information is retrieved.
 * @return The callback type as an integer, or `-1`
 *          if `This` is `null`
 *          or if the method is not found.
 */
jint GetCallbackType(JNIEnv *Env, jobject This);

/**
 * Retrieves the callback UUID from a Java object.
 *
 * @param Env JNI environment pointer.
 * @param This Java object for which the callback information is retrieved.
 * @return The callback UUID as a `FString`, or empty string
 *          if `This` is `null`
 *          or if the method is not found
 *          or if the Java value is null.
 */
FString GetCallbackUUID(JNIEnv *Env, jobject This);

/**
 * Retrieves whether the callback was triggered in Unreal Engine Blueprints from a Java object.
 *
 * @param Env JNI environment pointer.
 * @param This Java object for which the callback information is retrieved.
 * @return `true` if the callback was triggered in Unreal Engine Blueprints, `false`
 *          if `This` is `null`
 *          or if the method is not found.
 */
bool IsBroadcastCallback(JNIEnv *Env, jobject This);

/**
 * Convert the Java string to FString.
 *
 * @param Env JNI environment pointer.
 * @param String The Java string to be converted.
 * @return The converted C++ `FString`. If the Java string is `null`, an empty string is returned.
 */
FString ConvertString(JNIEnv *Env, jstring String);

/**
 * Convert the Java Uri to FString.
 *
 * @param Env JNI environment pointer.
 * @param Uri The Java `Uri` object to be converted.
 * @return The string representation of the Java Uri as a C++ `FString`. If the Uri is `null`, an empty string is returned.
 */
FString GetUriString(JNIEnv *Env, jobject Uri);

#endif