package co.ab180.airbridge.ue;

public class AirbridgeCallback {

    // The type of the callback
    private final AirbridgeCallbackType type;

    // The unique identifier (UUID) associated with the callback
    private final String uuid;

    // Indicates whether the callback was triggered in Unreal Engine Blueprints
    private final boolean useBroadcast;

    public AirbridgeCallback(AirbridgeCallbackType type, String uuid, boolean useBroadcast) {
        this.type = type;
        this.uuid = uuid;
        this.useBroadcast = useBroadcast;
    }

    public AirbridgeCallback(AirbridgeCallbackType type, String uuid) {
        this(type, uuid, false);
    }

    public AirbridgeCallback(AirbridgeCallbackType type) {
        this(type, null);
    }

    /**
     * Returns the callback type as an integer (ordinal value of AirbridgeCallbackType).
     *
     * @return The integer value representing the callback type (ordinal of AirbridgeCallbackType)
     */
    public int getCallbackType() {
        return type.ordinal();
    }

    /**
     * Returns the UUID associated with the callback.
     *
     * @return The UUID (String) of the callback, or null if not set
     */
    public String getUUID() {
        return uuid;
    }

    /**
     * Returns whether the callback was triggered in Unreal Engine Blueprints.
     *
     * @return true if the callback was triggered in Unreal Engine Blueprints, otherwise false
     */
    public boolean isBroadcast() {
        return useBroadcast;
    }
}